@@ -1,8 +1,11 @@
+pub mod channel;
 #[cfg(feature = "alloc")]
 pub mod event_bus;
 #[cfg(feature = "alloc")]
 pub mod mqtt;
 #[cfg(feature = "alloc")]
+pub mod signal;
+#[cfg(feature = "alloc")]
 pub mod timer;
 
 pub trait AsyncWrapper<U, S> {
